import cv2
import numpy as np 

# discretize image
img = cv2.imread('triangle.png')

background = np.zeros(img.shape, np.uint8) + 0.5  #create grey background (np.ones(img.shape, np.uint8)*255 for white)
img_gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY) #convert image to grayscale
ret, thresh = cv2.threshold(img_gray, 250, 255, cv2.THRESH_BINARY_INV) #set threshold 
contours, hierarchy = cv2.findContours(thresh, cv2.RETR_TREE, cv2.CHAIN_APPROX_SIMPLE) #find contours
largest_area = -1

#determine largest contour area
for cont in contours:
	if cv2.contourArea(cont) > largest_area:
		count = cont
		largest_area = cv2.contourArea(cont)


# triangle_3 (triangle.png): 0.01
# pentagon_5 (images.png): 0.01
# circle_8 (circle.png): 0.02
# mickey_mouse_12 (Mickey_Mouse_head_and_ears.png): 0.0255 for 12 points, 0.02 for 13
factor = 0.01

epsilon = factor * cv2.arcLength(count, True) #set epsilon - precision factor for approx shape
approximations = cv2.approxPolyDP(count, epsilon, True)	#get the approx points
cv2.drawContours(background, approximations, -1, (255, 0, 0), 3) 
print(approximations)
print(len(approximations))
cv2.imshow("Image", background) #plot the image
cv2.waitKey(0) #press any key to exit 

#Sources: https://stackoverflow.com/questions/41879315/opencv-visualize-polygonal-curves-extracted-with-cv2-approxpolydp
#https://docs.opencv.org/4.x/d4/d73/tutorial_py_contours_begin.html
