import numpy
import scipy.optimize as opt
import random
import sys


IMAGE_PLANE_X = 0


# generate matrix of distances between initial and final points
def bipartite_matrix_gen(init, final):
    graph = numpy.zeros((len(init), len(final)))
    for i_ind, i_vec in enumerate(init):
        for f_ind, f_vec in enumerate(final):
            graph[i_ind, f_ind] = numpy.linalg.norm(i_vec - f_vec)
    return graph

# final points obtained by discretizing the desired shape or image (specific to the triangle_3 model)
final_points = numpy.array([(0, 122, 2), (0, 6, 201), (0, 236, 201)])

# randomly generate initial points in (x, y, z) format
min_int = -1000
max_int = 1000
initial_points = []
for _ in range(len(final_points)):
    # by assumption, the x-coordinate is less than the x-value where image will be formed, y-coordinate can take any
    # value, the z-coordinate starts at 0
    initial_points.append( (random.uniform(min_int, IMAGE_PLANE_X), random.uniform(min_int, max_int), 0))
initial_points = numpy.array(initial_points)

# each row of this matrix represents the distance from that initial point to every final point
mx = bipartite_matrix_gen(initial_points,  final_points)

# calculate assignments that minimize the distances
row_ind, col_ind = opt.linear_sum_assignment(mx)

# output assignments
for index, assn in enumerate(col_ind):
    print(initial_points[index], ":\t", final_points[assn])





